@@ -36,8 +36,10 @@ import (
 	"github.com/qiniu/x/errors"
 )
 
+type dbgFlags int
+
 const (
-	DbgFlagLoad = 1 << iota
+	DbgFlagLoad dbgFlags = 1 << iota
 	DbgFlagLookup
 	DbgFlagAll = DbgFlagLoad | DbgFlagLookup
 )
@@ -55,41 +57,149 @@ func SetDisableRecover(disableRecover bool) {
 	enableRecover = !disableRecover
 }
 
-func SetDebug(flags int) {
+func SetDebug(flags dbgFlags) {
 	debugLoad = (flags & DbgFlagLoad) != 0
 	debugLookup = (flags & DbgFlagLookup) != 0
 }
 
 // -----------------------------------------------------------------------------
 
+// Recorder represents a compiling event recorder.
+type Recorder interface {
+	// Type maps expressions to their types, and for constant
+	// expressions, also their values. Invalid expressions are
+	// omitted.
+	//
+	// For (possibly parenthesized) identifiers denoting built-in
+	// functions, the recorded signatures are call-site specific:
+	// if the call result is not a constant, the recorded type is
+	// an argument-specific signature. Otherwise, the recorded type
+	// is invalid.
+	//
+	// The Types map does not record the type of every identifier,
+	// only those that appear where an arbitrary expression is
+	// permitted. For instance, the identifier f in a selector
+	// expression x.f is found only in the Selections map, the
+	// identifier z in a variable declaration 'var z int' is found
+	// only in the Defs map, and identifiers denoting packages in
+	// qualified identifiers are collected in the Uses map.
+	Type(ast.Expr, types.TypeAndValue)
+
+	// Instantiate maps identifiers denoting generic types or functions to their
+	// type arguments and instantiated type.
+	//
+	// For example, Instantiate will map the identifier for 'T' in the type
+	// instantiation T[int, string] to the type arguments [int, string] and
+	// resulting instantiated *Named type. Given a generic function
+	// func F[A any](A), Instances will map the identifier for 'F' in the call
+	// expression F(int(1)) to the inferred type arguments [int], and resulting
+	// instantiated *Signature.
+	//
+	// Invariant: Instantiating Uses[id].Type() with Instances[id].TypeArgs
+	// results in an equivalent of Instances[id].Type.
+	Instantiate(*ast.Ident, types.Instance)
+
+	// Def maps identifiers to the objects they define (including
+	// package names, dots "." of dot-imports, and blank "_" identifiers).
+	// For identifiers that do not denote objects (e.g., the package name
+	// in package clauses, or symbolic variables t in t := x.(type) of
+	// type switch headers), the corresponding objects are nil.
+	//
+	// For an embedded field, Def maps the field *Var it defines.
+	//
+	// Invariant: Defs[id] == nil || Defs[id].Pos() == id.Pos()
+	Def(id *ast.Ident, obj types.Object)
+
+	// Use maps identifiers to the objects they denote.
+	//
+	// For an embedded field, Use maps the *TypeName it denotes.
+	//
+	// Invariant: Uses[id].Pos() != id.Pos()
+	Use(id *ast.Ident, obj types.Object)
+
+	// Implicit maps nodes to their implicitly declared objects, if any.
+	// The following node and object types may appear:
+	//
+	//     node               declared object
+	//
+	//     *ast.ImportSpec    *PkgName for imports without renames
+	//     *ast.CaseClause    type-specific *Var for each type switch case clause (incl. default)
+	//     *ast.Field         anonymous parameter *Var (incl. unnamed results)
+	//
+	Implicit(node ast.Node, obj types.Object)
+
+	// Select maps selector expressions (excluding qualified identifiers)
+	// to their corresponding selections.
+	Select(*ast.SelectorExpr, *types.Selection)
+
+	// Scope maps ast.Nodes to the scopes they define. Package scopes are not
+	// associated with a specific node but with all files belonging to a package.
+	// Thus, the package scope can be found in the type-checked Package object.
+	// Scopes nest, with the Universe scope being the outermost scope, enclosing
+	// the package scope, which contains (one or more) files scopes, which enclose
+	// function scopes which in turn enclose statement and function literal scopes.
+	// Note that even though package-level functions are declared in the package
+	// scope, the function scopes are embedded in the file scope of the file
+	// containing the function declaration.
+	//
+	// The following node types may appear in Scopes:
+	//
+	//     *ast.File
+	//     *ast.FuncType
+	//     *ast.TypeSpec
+	//     *ast.BlockStmt
+	//     *ast.IfStmt
+	//     *ast.SwitchStmt
+	//     *ast.TypeSwitchStmt
+	//     *ast.CaseClause
+	//     *ast.CommClause
+	//     *ast.ForStmt
+	//     *ast.RangeStmt
+	//
+	Scope(ast.Node, *types.Scope)
+}
+
+// -----------------------------------------------------------------------------
+
 type Project = modfile.Project
 type Class = modfile.Class
 
 // Config of loading Go+ packages.
 type Config struct {
-	// Fset provides source position information for syntax trees and types.
+	// Types provides type information for the package (optional).
+	Types *types.Package
+
+	// Fset provides source position information for syntax trees and types (required).
 	// If Fset is nil, Load will use a new fileset, but preserve Fset's value.
 	Fset *token.FileSet
 
-	// WorkingDir is the directory in which to run gop compiler.
+	// WorkingDir is the directory in which to run gop compiler (optional).
+	// If WorkingDir is not set, os.Getwd() is used.
 	WorkingDir string
 
-	// TargetDir is the directory in which to generate Go files.
+	// TargetDir is the directory in which to generate Go files (optional).
+	// If TargetDir is not set, it is same as WorkingDir.
 	TargetDir string
 
-	// C2goBase specifies base of standard c2go packages.
+	// C2goBase specifies base of standard c2go packages (optional).
 	// Default is github.com/goplus/.
 	C2goBase string
 
-	// LookupPub lookups the c2go package pubfile (named c2go.a.pub).
+	// LookupPub lookups the c2go package pubfile named c2go.a.pub (required).
+	// See gop/x/c2go.LookupPub.
 	LookupPub func(pkgPath string) (pubfile string, err error)
 
-	// LookupClass lookups a class by specified file extension.
+	// LookupClass lookups a class by specified file extension (required).
+	// See (*github.com/goplus/mod/gopmod.Module).LookupClass.
 	LookupClass func(ext string) (c *Project, ok bool)
 
-	// An Importer resolves import paths to Packages.
+	// An Importer resolves import paths to Packages (optional).
 	Importer types.Importer
 
+	// A Recorder records existing objects including constants, variables and
+	// types etc (optional).
+	Recorder Recorder
+
 	// NoFileLine = true means not to generate file line comments.
 	NoFileLine bool
 
@@ -106,6 +216,27 @@ type Config struct {
 	Outline bool
 }
 
+type goxRecorder struct {
+	rec Recorder
+}
+
+// Member maps identifiers to the objects they denote.
+func (p *goxRecorder) Member(id ast.Node, obj types.Object) {
+	tv := types.TypeAndValue{Type: obj.Type()}
+	switch v := id.(type) {
+	case *ast.SelectorExpr:
+		sel := v.Sel
+		// TODO: record event for a Go ident
+		if _, ok := fromgo.CheckIdent(sel); !ok {
+			p.rec.Use(sel, obj)
+			p.rec.Type(v, tv)
+		}
+	case *ast.Ident: // it's in a classfile and impossible converted from Go
+		p.rec.Use(v, obj)
+		p.rec.Type(v, tv)
+	}
+}
+
 type nodeInterp struct {
 	fset       *token.FileSet
 	files      map[string]*ast.File
@@ -164,13 +295,9 @@ func initLoader(ctx *pkgCtx, syms map[string]loader, start token.Pos, name strin
 		return
 	}
 	if old, ok := syms[name]; ok {
-		var pos token.Position
-		if start != token.NoPos {
-			pos = ctx.Position(start)
-		}
 		oldpos := ctx.Position(old.pos())
-		ctx.handleCodeErrorf(
-			&pos, "%s redeclared in this block\n\tprevious declaration at %v", name, oldpos)
+		ctx.handleErrorf(
+			start, "%s redeclared in this block\n\tprevious declaration at %v", name, oldpos)
 		return
 	}
 	syms[name] = &baseLoader{start: start, fn: fn}
@@ -198,9 +325,9 @@ func getTypeLoader(ctx *pkgCtx, syms map[string]loader, start token.Pos, name st
 			if ld.start == token.NoPos {
 				ld.start = start
 			} else {
-				pos := ctx.Position(start)
-				ctx.handleCodeErrorf(&pos, "%s redeclared in this block\n\tprevious declaration at %v",
-					name, ctx.Position(ld.start))
+				ctx.handleErrorf(
+					start, "%s redeclared in this block\n\tprevious declaration at %v",
+					name, ctx.Position(ld.pos()))
 			}
 			return ld
 		}
@@ -258,25 +385,40 @@ type pkgCtx struct {
 	inInst   int             // toType in generic instance
 }
 
+type pkgImp struct {
+	*gox.PkgRef
+	pkgName *types.PkgName
+}
+
 type blockCtx struct {
 	*pkgCtx
 	pkg          *gox.Package
 	cb           *gox.CodeBuilder
 	fset         *token.FileSet
-	imports      map[string]*gox.PkgRef
+	imports      map[string]pkgImp
 	lookups      []*gox.PkgRef
 	clookups     []*cpackages.PkgRef
 	tlookup      *typeParamLookup
 	c2goBase     string // default is `github.com/goplus/`
 	targetDir    string
 	classRecv    *ast.FieldList // available when gmxSettings != nil
+	fileScope    *types.Scope   // only valid when isGopFile
+	rec          Recorder
 	fileLine     bool
 	relativePath bool
 	isClass      bool
+	isGopFile    bool // is Go+ file or not
 }
 
-func (bc *blockCtx) findImport(name string) (pr *gox.PkgRef, ok bool) {
-	pr, ok = bc.imports[name]
+func (bc *blockCtx) recorder() Recorder {
+	if bc.isGopFile {
+		return bc.rec
+	}
+	return nil
+}
+
+func (bc *blockCtx) findImport(name string) (pi pkgImp, ok bool) {
+	pi, ok = bc.imports[name]
 	return
 }
 
@@ -298,6 +440,11 @@ func (p *pkgCtx) handleCodeErrorf(pos *token.Position, format string, args ...in
 	p.handleErr(newCodeErrorf(pos, format, args...))
 }
 
+func (p *pkgCtx) handleErrorf(start token.Pos, format string, args ...interface{}) {
+	pos := p.Position(start)
+	p.handleErr(newCodeErrorf(&pos, format, args...))
+}
+
 func (p *pkgCtx) handleErr(err error) {
 	p.errs = append(p.errs, err)
 }
@@ -382,6 +529,7 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 		syms: make(map[string]loader), nodeInterp: interp, generics: make(map[string]bool),
 	}
 	confGox := &gox.Config{
+		Types:           conf.Types,
 		Fset:            fset,
 		Importer:        conf.Importer,
 		LoadNamed:       ctx.loadNamed,
@@ -392,6 +540,9 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 		NoSkipConstant:  conf.NoSkipConstant,
 		PkgPathIox:      ioxPkgPath,
 	}
+	if conf.Recorder != nil {
+		confGox.Recorder = &goxRecorder{rec: conf.Recorder}
+	}
 	if enableRecover {
 		defer func() {
 			if e := recover(); e != nil {
@@ -420,10 +571,14 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 	}
 	for fpath, f := range files {
 		fileLine := !conf.NoFileLine
+		fileScope := types.NewScope(p.Types.Scope(), f.Pos(), f.End(), fpath)
 		ctx := &blockCtx{
-			pkg: p, pkgCtx: ctx, cb: p.CB(), fset: p.Fset, targetDir: targetDir,
-			fileLine: fileLine, relativePath: conf.RelativePath, isClass: f.IsClass,
-			c2goBase: c2goBase(conf.C2goBase), imports: make(map[string]*gox.PkgRef),
+			pkg: p, pkgCtx: ctx, cb: p.CB(), fset: p.Fset, targetDir: targetDir, fileScope: fileScope,
+			fileLine: fileLine, relativePath: conf.RelativePath, isClass: f.IsClass, rec: conf.Recorder,
+			c2goBase: c2goBase(conf.C2goBase), imports: make(map[string]pkgImp), isGopFile: true,
+		}
+		if rec := ctx.rec; rec != nil {
+			rec.Scope(f, fileScope)
 		}
 		preloadGopFile(p, ctx, fpath, f, conf)
 	}
@@ -434,7 +589,7 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 		gofiles = append(gofiles, f)
 		ctx := &blockCtx{
 			pkg: p, pkgCtx: ctx, cb: p.CB(), fset: p.Fset, targetDir: targetDir,
-			imports: make(map[string]*gox.PkgRef),
+			imports: make(map[string]pkgImp),
 		}
 		preloadFile(p, ctx, fpath, f, false, false)
 	}
@@ -686,7 +841,7 @@ retry:
 		typ = t.X
 		goto retry
 	}
-	return nil
+	panic("TODO: parseTypeEmbedName unexpected")
 }
 
 func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, gopFile, genFnBody bool) {
@@ -752,7 +907,8 @@ func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, gopFil
 					if debugLoad {
 						log.Println("==> Preload type", name)
 					}
-					ld := getTypeLoader(parent, syms, t.Name.Pos(), name)
+					pos := t.Name.Pos()
+					ld := getTypeLoader(parent, syms, pos, name)
 					defs := ctx.pkg.NewTypeDefs()
 					if gopFile {
 						ld.typ = func() {
@@ -762,13 +918,13 @@ func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, gopFil
 								if debugLoad {
 									log.Println("==> Load > AliasType", name)
 								}
-								ctx.pkg.AliasType(name, toType(ctx, t.Type), t.Pos())
+								defs.AliasType(name, toType(ctx, t.Type), t.Pos())
 								return
 							}
 							if debugLoad {
 								log.Println("==> Load > NewType", name)
 							}
-							decl := defs.NewType(name)
+							decl := defs.NewType(name, pos)
 							if t.Doc != nil {
 								defs.SetComments(t.Doc)
 							} else if d.Doc != nil {
@@ -779,6 +935,9 @@ func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, gopFil
 									log.Println("==> Load > InitType", name)
 								}
 								decl.InitType(ctx.pkg, toType(ctx, t.Type))
+								if rec := ctx.recorder(); rec != nil {
+									rec.Def(t.Name, decl.Type().Obj())
+								}
 							}
 						}
 					} else {
@@ -872,6 +1031,7 @@ func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl, genBody bool) {
 			log.Printf("==> Load method %v.%s\n", recv.Type(), name)
 		}
 	}
+	pkg := ctx.pkg
 	if d.Operator {
 		if recv != nil { // binary op
 			if v, ok := binaryGopNames[name]; ok {
@@ -880,7 +1040,7 @@ func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl, genBody bool) {
 		} else { // unary op
 			if v, ok := unaryGopNames[name]; ok {
 				name = v
-				at := ctx.pkg.Types
+				at := pkg.Types
 				arg1 := d.Type.Params.List[0]
 				typ := toType(ctx, arg1.Type)
 				recv = types.NewParam(arg1.Pos(), at, arg1.Names[0].Name, typ)
@@ -889,7 +1049,7 @@ func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl, genBody bool) {
 		}
 	}
 	sig := toFuncType(ctx, d.Type, recv, d)
-	fn, err := ctx.pkg.NewFuncWith(d.Pos(), name, sig, func() token.Pos {
+	fn, err := pkg.NewFuncWith(d.Name.Pos(), name, sig, func() token.Pos {
 		return d.Recv.List[0].Type.Pos()
 	})
 	if err != nil {
@@ -897,7 +1057,13 @@ func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl, genBody bool) {
 		return
 	}
 	if d.Doc != nil {
-		fn.SetComments(d.Doc)
+		fn.SetComments(pkg, d.Doc)
+	}
+	if rec := ctx.recorder(); rec != nil {
+		rec.Def(d.Name, fn.Func)
+		if recv == nil {
+			ctx.fileScope.Insert(fn.Func)
+		}
 	}
 	if genBody {
 		if body := d.Body; body != nil {
@@ -963,7 +1129,7 @@ var unaryGopNames = map[string]string{
 }
 
 func loadFuncBody(ctx *blockCtx, fn *gox.Func, body *ast.BlockStmt, src ast.Node) {
-	cb := fn.BodyStart(ctx.pkg)
+	cb := fn.BodyStart(ctx.pkg, body)
 	compileStmts(ctx, body.List)
 	cb.End(src)
 }
@@ -995,9 +1161,25 @@ func loadImport(ctx *blockCtx, spec *ast.ImportSpec) {
 	} else {
 		pkg = ctx.pkg.Import(simplifyGopPackage(pkgPath), spec)
 	}
+
+	var pos token.Pos
 	var name string
-	if spec.Name != nil {
-		name = spec.Name.Name
+	var specName = spec.Name
+	if specName != nil {
+		name, pos = specName.Name, specName.Pos()
+	} else {
+		name, pos = pkg.Types.Name(), spec.Path.Pos()
+	}
+	pkgName := types.NewPkgName(pos, ctx.pkg.Types, name, pkg.Types)
+	if rec := ctx.recorder(); rec != nil {
+		if specName != nil {
+			rec.Def(specName, pkgName)
+		} else {
+			rec.Implicit(spec, pkgName)
+		}
+	}
+
+	if specName != nil {
 		if name == "." {
 			ctx.lookups = append(ctx.lookups, pkg)
 			return
@@ -1006,10 +1188,8 @@ func loadImport(ctx *blockCtx, spec *ast.ImportSpec) {
 			pkg.MarkForceUsed()
 			return
 		}
-	} else {
-		name = pkg.Types.Name()
 	}
-	ctx.imports[name] = pkg
+	ctx.imports[name] = pkgImp{pkg, pkgName}
 }
 
 func loadConstSpecs(ctx *blockCtx, cdecl *gox.ConstDefs, specs []ast.Spec) {
@@ -1020,12 +1200,14 @@ func loadConstSpecs(ctx *blockCtx, cdecl *gox.ConstDefs, specs []ast.Spec) {
 }
 
 func loadConsts(ctx *blockCtx, cdecl *gox.ConstDefs, v *ast.ValueSpec, iotav int) {
-	names := makeNames(v.Names)
+	vNames := v.Names
+	names := makeNames(vNames)
 	if v.Values == nil {
 		if debugLoad {
 			log.Println("==> Load const", names)
 		}
 		cdecl.Next(iotav, v.Pos(), names...)
+		defNames(ctx, vNames, nil)
 		return
 	}
 	var typ types.Type
@@ -1042,6 +1224,7 @@ func loadConsts(ctx *blockCtx, cdecl *gox.ConstDefs, v *ast.ValueSpec, iotav int
 		return len(v.Values)
 	}
 	cdecl.New(fn, iotav, v.Pos(), typ, names...)
+	defNames(ctx, v.Names, nil)
 }
 
 func loadVars(ctx *blockCtx, v *ast.ValueSpec, global bool) {
@@ -1093,6 +1276,20 @@ func loadVars(ctx *blockCtx, v *ast.ValueSpec, global bool) {
 		}
 		cb.EndInit(nv)
 	}
+	defNames(ctx, v.Names, scope)
+}
+
+func defNames(ctx *blockCtx, names []*ast.Ident, scope *types.Scope) {
+	if rec := ctx.recorder(); rec != nil {
+		if scope == nil {
+			scope = ctx.cb.Scope()
+		}
+		for _, name := range names {
+			if o := scope.Lookup(name.Name); o != nil {
+				rec.Def(name, o)
+			}
+		}
+	}
 }
 
 func makeNames(vals []*ast.Ident) []string {
