@@ -50,6 +50,7 @@ func init() {
 	gblConf = &cl.Config{
 		Fset:          gblFset,
 		Importer:      imp,
+		Recorder:      gopRecorder{},
 		LookupClass:   lookupClass,
 		LookupPub:     lookupPub,
 		C2goBase:      "github.com/goplus/gop/cl/internal",
@@ -152,10 +153,10 @@ for line <- open("foo.txt")! {
 `, `package main
 
 import (
-	fmt "fmt"
-	os "os"
-	iox "github.com/goplus/gop/builtin/iox"
-	errors "github.com/qiniu/x/errors"
+	"fmt"
+	"os"
+	"github.com/goplus/gop/builtin/iox"
+	"github.com/qiniu/x/errors"
 )
 
 func main() {
@@ -189,9 +190,9 @@ for line <- os.Stdin {
 `, `package main
 
 import (
-	fmt "fmt"
-	os "os"
-	iox "github.com/goplus/gop/builtin/iox"
+	"fmt"
+	"os"
+	"github.com/goplus/gop/builtin/iox"
 )
 
 func main() {
@@ -219,9 +220,9 @@ for line <- lines(r) {
 `, `package main
 
 import (
-	fmt "fmt"
-	iox "github.com/goplus/gop/builtin/iox"
-	io "io"
+	"fmt"
+	"github.com/goplus/gop/builtin/iox"
+	"io"
 )
 
 var r io.Reader
@@ -293,7 +294,7 @@ type T struct{}
 println(&T{},&Point{10,20})
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type T struct {
 }
@@ -310,7 +311,7 @@ for i <- :10, i%3 == 0 {
 	println i
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	for i := 0; i < 10; i += 1 {
@@ -333,7 +334,7 @@ d := fvec([])
 println a, b, c, d
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type fvec []float64
 type foo float64
@@ -537,8 +538,8 @@ println "The Go+ Language for", fields.join(", ")
 `, `package main
 
 import (
-	fmt "fmt"
-	strings "strings"
+	"fmt"
+	"strings"
 )
 
 func main() {
@@ -554,7 +555,7 @@ p := println
 p "Hello world"
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	p := fmt.Println
@@ -920,8 +921,8 @@ func main() {
 }`, `package main
 
 import (
-	fmt "fmt"
-	errors "github.com/qiniu/x/errors"
+	"fmt"
+	"github.com/qiniu/x/errors"
 )
 
 func t() (int, int, error) {
@@ -954,7 +955,7 @@ func main() {
 	t()!
 }`, `package main
 
-import errors "github.com/qiniu/x/errors"
+import "github.com/qiniu/x/errors"
 
 func t() error {
 	return nil
@@ -997,7 +998,7 @@ func (a *A) String() string {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type AA interface {
 	String() string
@@ -1042,7 +1043,7 @@ func (a *A) String() string {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type AA interface {
 	String() string
@@ -1083,7 +1084,7 @@ func main() {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	{
@@ -1135,7 +1136,7 @@ func main() {
 var i int
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println(i)
@@ -1178,7 +1179,7 @@ func main() {
 var i = 100
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println(i)
@@ -1198,7 +1199,7 @@ func main() {
 	println(n)
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	v := []uint64{2, 3, 5}
@@ -1223,7 +1224,7 @@ func consume(xchg chan int) {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func consume(xchg chan int) {
 	select {
@@ -1396,7 +1397,7 @@ func main() {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type Shape interface {
 	Area() float64
@@ -1441,7 +1442,7 @@ type BigInt struct {
 	*big.Int
 }`, `package main
 
-import big "math/big"
+import "math/big"
 
 type BigInt struct {
 	*big.Int
@@ -1461,10 +1462,10 @@ func foo(script string) {
 `, `package main
 
 import (
-	fmt "fmt"
-	goptest "github.com/goplus/gop/ast/goptest"
-	errors "github.com/qiniu/x/errors"
-	gopq "github.com/goplus/gop/ast/gopq"
+	"fmt"
+	"github.com/goplus/gop/ast/goptest"
+	"github.com/qiniu/x/errors"
+	"github.com/goplus/gop/ast/gopq"
 )
 
 func foo(script string) {
@@ -1495,10 +1496,10 @@ func foo(script string) {
 `, `package main
 
 import (
-	fmt "fmt"
-	goptest "github.com/goplus/gop/ast/goptest"
-	errors "github.com/qiniu/x/errors"
-	gopq "github.com/goplus/gop/ast/gopq"
+	"fmt"
+	"github.com/goplus/gop/ast/goptest"
+	"github.com/qiniu/x/errors"
+	"github.com/goplus/gop/ast/gopq"
 )
 
 func foo(script string) {
@@ -1527,8 +1528,8 @@ func add(x, y string) (int, error) {
 `, `package main
 
 import (
-	strconv "strconv"
-	errors "github.com/qiniu/x/errors"
+	"strconv"
+	"github.com/qiniu/x/errors"
 )
 
 func add(x string, y string) (int, error) {
@@ -1568,7 +1569,7 @@ func addSafe(x, y string) int {
 }
 `, `package main
 
-import strconv "strconv"
+import "strconv"
 
 func addSafe(x string, y string) int {
 	return func() (_gop_ret int) {
@@ -1596,8 +1597,8 @@ var ret int = println("Hi")!
 `, `package main
 
 import (
-	fmt "fmt"
-	errors "github.com/qiniu/x/errors"
+	"fmt"
+	"github.com/qiniu/x/errors"
 )
 
 var ret int = func() (_gop_ret int) {
@@ -1621,7 +1622,7 @@ func mkdir(name string) error {
 mkdir! "foo"
 `, `package main
 
-import errors "github.com/qiniu/x/errors"
+import "github.com/qiniu/x/errors"
 
 func mkdir(name string) error {
 	return nil
@@ -1649,7 +1650,7 @@ func foo() (func(), error) {
 foo()!()
 `, `package main
 
-import errors "github.com/qiniu/x/errors"
+import "github.com/qiniu/x/errors"
 
 func foo() (func(), error) {
 	return nil, nil
@@ -1698,7 +1699,7 @@ var x, y uint128
 var z uint128 = x + y
 `, `package main
 
-import ng "github.com/goplus/gop/builtin/ng"
+import "github.com/goplus/gop/builtin/ng"
 
 var x, y ng.Uint128
 var z ng.Uint128 = x.Gop_Add__1(y)
@@ -1711,7 +1712,7 @@ var x, y int128
 var z int128 = x + y
 `, `package main
 
-import ng "github.com/goplus/gop/builtin/ng"
+import "github.com/goplus/gop/builtin/ng"
 
 var x, y ng.Int128
 var z ng.Int128 = x.Gop_Add__1(y)
@@ -1724,7 +1725,7 @@ var x, y bigint
 var z bigint = x + y
 `, `package main
 
-import ng "github.com/goplus/gop/builtin/ng"
+import "github.com/goplus/gop/builtin/ng"
 
 var x, y ng.Bigint
 var z ng.Bigint = x.Gop_Add(y)
@@ -1737,8 +1738,8 @@ var x = 1r
 `, `package main
 
 import (
-	ng "github.com/goplus/gop/builtin/ng"
-	big "math/big"
+	"github.com/goplus/gop/builtin/ng"
+	"math/big"
 )
 
 var x = ng.Bigint_Init__1(big.NewInt(1))
@@ -1750,7 +1751,7 @@ func TestUint128Lit(t *testing.T) {
 var x uint128 = 1
 `, `package main
 
-import ng "github.com/goplus/gop/builtin/ng"
+import "github.com/goplus/gop/builtin/ng"
 
 var x ng.Uint128 = ng.Uint128_Init__0(1)
 `)
@@ -1761,7 +1762,7 @@ func TestInt128Lit(t *testing.T) {
 var x int128 = 1
 `, `package main
 
-import ng "github.com/goplus/gop/builtin/ng"
+import "github.com/goplus/gop/builtin/ng"
 
 var x ng.Int128 = ng.Int128_Init__0(1)
 `)
@@ -1773,8 +1774,8 @@ var x = 1/2r
 `, `package main
 
 import (
-	ng "github.com/goplus/gop/builtin/ng"
-	big "math/big"
+	"github.com/goplus/gop/builtin/ng"
+	"math/big"
 )
 
 var x = ng.Bigrat_Init__2(big.NewRat(1, 2))
@@ -1787,8 +1788,8 @@ var x = 3 + 1/2r
 `, `package main
 
 import (
-	ng "github.com/goplus/gop/builtin/ng"
-	big "math/big"
+	"github.com/goplus/gop/builtin/ng"
+	"math/big"
 )
 
 var x = ng.Bigrat_Init__2(big.NewRat(7, 2))
@@ -1804,8 +1805,8 @@ var z = 100 + y
 `, `package main
 
 import (
-	ng "github.com/goplus/gop/builtin/ng"
-	big "math/big"
+	"github.com/goplus/gop/builtin/ng"
+	"math/big"
 )
 
 var x = ng.Bigrat_Init__2(big.NewRat(7, 2))
@@ -1918,7 +1919,7 @@ var x bigint
 x += 3
 `, `package main
 
-import ng "github.com/goplus/gop/builtin/ng"
+import "github.com/goplus/gop/builtin/ng"
 
 var x ng.Bigint
 
@@ -1935,8 +1936,8 @@ x *= 2
 `, `package main
 
 import (
-	ng "github.com/goplus/gop/builtin/ng"
-	big "math/big"
+	"github.com/goplus/gop/builtin/ng"
+	"math/big"
 )
 
 func main() {
@@ -1953,8 +1954,8 @@ x *= 2r
 `, `package main
 
 import (
-	ng "github.com/goplus/gop/builtin/ng"
-	big "math/big"
+	"github.com/goplus/gop/builtin/ng"
+	"math/big"
 )
 
 func main() {
@@ -2205,12 +2206,12 @@ func main() {
 }
 `, `package main
 
+type bar = foo
 type foo struct {
 	p *foo
 	A int
 	B string `+"`tag1:123`"+`
 }
-type bar = foo
 
 func main() {
 	type a struct {
@@ -2227,7 +2228,7 @@ go println("Hi")
 defer println("Go+")
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	go fmt.Println("Hi")
@@ -2247,7 +2248,7 @@ for {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	a := []float64{1, 3.4, 5}
@@ -2284,7 +2285,7 @@ for range a {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	a := []float64{1, 3.4, 5}
@@ -2322,7 +2323,7 @@ for k, v := range new(foo) {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type foo struct {
 }
@@ -2350,7 +2351,7 @@ for v <- new(foo) {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type foo struct {
 }
@@ -2385,7 +2386,7 @@ for k, v <- new(foo) {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type fooIter struct {
 }
@@ -2421,7 +2422,7 @@ func (p *foo) Gop_Enum(c func(val string)) {
 println([v for v <- new(foo)])
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type foo struct {
 }
@@ -2472,7 +2473,7 @@ for k, v <- newFoo() {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type fooIter struct {
 	data *foo
@@ -2521,7 +2522,7 @@ for i, x <- [1, 3, 5, 7, 11, 13, 17] {
 println("sum(5,7,11,13,17):", sum)
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	sum := 0
@@ -2692,7 +2693,7 @@ x := [[a, b] for a <- arr, a < b for b <- arr, b > 2]
 println("x:", x)
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	arr := []float64{1, 2, 3, 4.1, 5, 6}
@@ -2798,8 +2799,8 @@ println("x:", x)
 `, `package main
 
 import (
-	fmt "fmt"
-	strings "strings"
+	"fmt"
+	"strings"
 )
 
 func main() {
@@ -2822,7 +2823,7 @@ func bar(p pfoo) {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type foo struct {
 	req int
@@ -2851,7 +2852,7 @@ a.B = "Hi"
 flag.Usage = nil
 `, `package main
 
-import flag "flag"
+import "flag"
 
 func main() {
 	a := &struct {
@@ -2911,7 +2912,7 @@ func (M) Bar() {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type M int
 
@@ -2958,7 +2959,7 @@ var d = -a       // TODO: -a have no return value!
 var e = a!=b
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type foo struct {
 }
@@ -2992,7 +2993,7 @@ var e = a.Gop_NE(b)
 func TestCmdlineNoEOL(t *testing.T) {
 	gopClTest(t, `println "Hi"`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println("Hi")
@@ -3007,7 +3008,7 @@ func main() {
 	fmt.println "Hi"
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println("Hi")
@@ -3021,7 +3022,7 @@ func TestDotImport(t *testing.T) {
 var a = round(1.2)
 `, `package main
 
-import math "math"
+import "math"
 
 var a = math.Round(1.2)
 `)
@@ -3033,7 +3034,7 @@ func TestLocalImport(t *testing.T) {
 var a = spx.TestIntValue
 `, `package main
 
-import spx "github.com/goplus/gop/cl/internal/spx"
+import "github.com/goplus/gop/cl/internal/spx"
 
 var a = spx.TestIntValue
 `)
@@ -3068,7 +3069,7 @@ func TestAnonymousImport(t *testing.T) {
 printf("Hello Go+\n")
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println("Hello")
@@ -3107,7 +3108,7 @@ func main() {
 	fmt.Println("Hi")
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	const (
@@ -3132,7 +3133,7 @@ if t := false; t {
 println("x:", x)
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	x := 0
@@ -3172,7 +3173,7 @@ default:
 println("x:", x)
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	x := 0
@@ -3213,7 +3214,7 @@ default:
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	v := "Hello"
@@ -3245,7 +3246,7 @@ label:
 	}
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	a := []float64{1, 3.4, 5}
@@ -3272,7 +3273,7 @@ func main() {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func foo(format string, args ...interface {
 }) (int, error) {
@@ -3310,7 +3311,7 @@ func(v string) {
 }("Hello")
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	func(v string) {
@@ -3451,7 +3452,7 @@ Do => {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func Do(func()) {
 }
@@ -3620,7 +3621,7 @@ func bar(foo func(string, ...interface{}) (int, error)) {
 bar(fmt.Printf)
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func bar(foo func(string, ...interface {
 }) (int, error)) {
@@ -3657,8 +3658,8 @@ fmt.Println(printf("Hello, %v\n", "Go+"))
 `, `package main
 
 import (
-	fmt "fmt"
-	strings "strings"
+	"fmt"
+	"strings"
 )
 
 func foo(x string) string {
@@ -3686,7 +3687,7 @@ func TestFuncCall(t *testing.T) {
 
 fmt.Println("Hello")`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println("Hello")
@@ -3704,7 +3705,7 @@ func foo(args ...interface{}) {
 func main() {
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func foo(args ...interface {
 }) {
@@ -3727,7 +3728,7 @@ func foo(args ...interface{}) {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	foo("Hello", 123)
@@ -3763,7 +3764,7 @@ func TestAssignUnderscore(t *testing.T) {
 _, err := log.Println("Hello")
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	_, err := fmt.Println("Hello")
@@ -3810,8 +3811,8 @@ println(rmap)
 `, `package main
 
 import (
-	fmt "fmt"
-	foo "github.com/goplus/gop/cl/internal/gop-in-go/foo"
+	"fmt"
+	"github.com/goplus/gop/cl/internal/gop-in-go/foo"
 )
 
 func main() {
@@ -3856,8 +3857,8 @@ func New() Result {
 `, `package main
 
 import (
-	reflect "reflect"
-	testing "testing"
+	"reflect"
+	"testing"
 )
 
 type Repo struct {
@@ -3901,7 +3902,7 @@ for i $ :10 {
 	println(i)
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	for i := 0; i < 10; i += 1 {
@@ -3914,7 +3915,7 @@ for i $ 1:10:3 {
 	println(i)
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	for i := 1; i < 10; i += 3 {
@@ -3930,7 +3931,7 @@ for i $ 1:10:2 {
 	println(i)
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	for i := 1; i < 10; i += 2 {
@@ -3946,7 +3947,7 @@ for i $ 1:10 {
 	println(i)
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	for i := 1; i < 10; i += 1 {
@@ -3962,7 +3963,7 @@ for i $ :10:2 {
 	println(i)
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	for i := 0; i < 10; i += 2 {
@@ -3978,7 +3979,7 @@ for range :10 {
 	println("Hi")
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	for _gop_k := 0; _gop_k < 10; _gop_k += 1 {
@@ -3994,7 +3995,7 @@ for _ <- :10 {
 	println("Hi")
 }`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	for _gop_k := 0; _gop_k < 10; _gop_k += 1 {
@@ -4010,8 +4011,8 @@ println [x for x <- 0:3:1]
 `, `package main
 
 import (
-	fmt "fmt"
-	builtin "github.com/goplus/gop/builtin"
+	"fmt"
+	"github.com/goplus/gop/builtin"
 )
 
 func main() {
@@ -4057,7 +4058,7 @@ func TestRangeExpr8(t *testing.T) {
 	}
 	`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type T struct {
 }
@@ -4101,7 +4102,7 @@ func TestRangeExpr9(t *testing.T) {
 	}
 	`, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type T struct {
 }
@@ -4157,7 +4158,7 @@ func TestNoEntrypoint(t *testing.T) {
 	gopClTest(t, `println("init")
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println("init")
@@ -4167,7 +4168,7 @@ func main() {
 println("init")
 `, `package bar
 
-import fmt "fmt"
+import "fmt"
 
 func init() {
 	fmt.Println("init")
@@ -4191,7 +4192,7 @@ println []
 println {}
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println([]interface {
@@ -4215,7 +4216,7 @@ type Point struct {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 type Point struct {
 	X int
@@ -4238,7 +4239,7 @@ println "hello"
 println("hello")
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Print()
@@ -4257,7 +4258,7 @@ var a any = 100
 println(a)
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 var a interface {
 } = 100
@@ -4284,7 +4285,7 @@ func test() {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func test() {
 	fmt.Println("hello")
@@ -4299,7 +4300,7 @@ func main() {
 }
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println("hello")
@@ -4312,7 +4313,7 @@ func TestCommandNotExpr(t *testing.T) {
 println !true
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println(false)
@@ -4323,7 +4324,7 @@ a := true
 println !a
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	a := true
@@ -4334,7 +4335,7 @@ func main() {
 println !func() bool { return true }()
 `, `package main
 
-import fmt "fmt"
+import "fmt"
 
 func main() {
 	fmt.Println(!func() bool {
@@ -4388,7 +4389,7 @@ var (
 func test(){}
 `, `package main
 
-import bytes "bytes"
+import "bytes"
 
 type Rect struct {
 	bytes.Buffer
@@ -4405,7 +4406,7 @@ var (
 func test(){}
 `, `package main
 
-import bytes "bytes"
+import "bytes"
 
 type Rect struct {
 	*bytes.Buffer
@@ -4424,7 +4425,7 @@ var (
 func test(){}
 `, `package main
 
-import bytes "bytes"
+import "bytes"
 
 type Rect struct {
 	*bytes.Buffer `+"`spec:\"buffer\"`"+`
@@ -4492,7 +4493,7 @@ n.onKey ["a"],nil,key => {
 }
 `, `package main
 
-import foo "github.com/goplus/gop/cl/internal/overload/foo"
+import "github.com/goplus/gop/cl/internal/overload/foo"
 
 type Mesh struct {
 }
