@@ -38,11 +38,22 @@ func toRecv(ctx *blockCtx, recv *ast.FieldList) *types.Var {
 		name = v.Names[0].Name
 	}
 	typ, star := getRecvType(v.Type)
-	t := toType(ctx, typ)
+	id, ok := typ.(*ast.Ident)
+	if !ok {
+		panic("TODO: getRecvType")
+	}
+	t := toIdentType(ctx, id)
 	if star {
 		t = types.NewPointer(t)
 	}
-	return ctx.pkg.NewParam(v.Pos(), name, t)
+	ret := ctx.pkg.NewParam(v.Pos(), name, t)
+	if rec := ctx.recorder(); rec != nil {
+		dRecv := recv.List[0]
+		if names := dRecv.Names; len(names) == 1 {
+			rec.Def(names[0], ret)
+		}
+	}
+	return ret
 }
 
 func getRecvTypeName(ctx *pkgCtx, recv *ast.FieldList, handleErr bool) (string, bool) {
@@ -90,7 +101,11 @@ func toParam(ctx *blockCtx, fld *ast.Field, args []*gox.Param) []*gox.Param {
 		return append(args, pkg.NewParam(fld.Pos(), "", typ))
 	}
 	for _, name := range fld.Names {
-		args = append(args, pkg.NewParam(name.Pos(), name.Name, typ))
+		param := pkg.NewParam(name.Pos(), name.Name, typ)
+		args = append(args, param)
+		if rec := ctx.recorder(); rec != nil {
+			rec.Def(name, param)
+		}
 	}
 	return args
 }
@@ -100,14 +115,12 @@ func toParam(ctx *blockCtx, fld *ast.Field, args []*gox.Param) []*gox.Param {
 func toType(ctx *blockCtx, typ ast.Expr) types.Type {
 	switch v := typ.(type) {
 	case *ast.Ident:
-		if enableTypeParams {
-			ctx.idents = append(ctx.idents, v)
-			defer func() {
-				ctx.idents = ctx.idents[:len(ctx.idents)-1]
-			}()
-		}
+		ctx.idents = append(ctx.idents, v)
+		defer func() {
+			ctx.idents = ctx.idents[:len(ctx.idents)-1]
+		}()
 		typ := toIdentType(ctx, v)
-		if enableTypeParams && ctx.inInst == 0 {
+		if ctx.inInst == 0 {
 			if t, ok := typ.(*types.Named); ok {
 				if namedIsTypeParams(ctx, t) {
 					pos := ctx.idents[0].Pos()
@@ -117,7 +130,8 @@ func toType(ctx *blockCtx, typ ast.Expr) types.Type {
 							break
 						}
 					}
-					panic(ctx.newCodeErrorf(pos, "cannot use generic type %v without instantiation", t.Obj().Type()))
+					ctx.handleErrorf(pos, "cannot use generic type %v without instantiation", t.Obj().Type())
+					return types.Typ[types.Invalid]
 				}
 			}
 		}
@@ -142,7 +156,7 @@ func toType(ctx *blockCtx, typ ast.Expr) types.Type {
 		return toFuncType(ctx, v, nil, nil)
 	case *ast.SelectorExpr:
 		typ := toExternalType(ctx, v)
-		if enableTypeParams && ctx.inInst == 0 {
+		if ctx.inInst == 0 {
 			if t, ok := typ.(*types.Named); ok {
 				if namedIsTypeParams(ctx, t) {
 					panic(ctx.newCodeErrorf(v.Pos(), "cannot use generic type %v without instantiation", t.Obj().Type()))
@@ -178,15 +192,25 @@ func toChanType(ctx *blockCtx, v *ast.ChanType) *types.Chan {
 }
 
 func toExternalType(ctx *blockCtx, v *ast.SelectorExpr) types.Type {
-	name := v.X.(*ast.Ident).Name
-	if pr, ok := ctx.findImport(name); ok {
-		o := pr.TryRef(v.Sel.Name)
+	id := v.X.(*ast.Ident)
+	name := id.Name
+	if pi, ok := ctx.findImport(name); ok {
+		rec := ctx.recorder()
+		if rec != nil {
+			rec.Use(id, pi.pkgName)
+		}
+		o := pi.TryRef(v.Sel.Name)
 		if t, ok := o.(*types.TypeName); ok {
+			if rec != nil {
+				rec.Use(v.Sel, t)
+			}
 			return t.Type()
 		}
-		panic(ctx.newCodeErrorf(v.Pos(), "%s.%s is not a type", name, v.Sel.Name))
+		ctx.handleErrorf(v.Pos(), "%s.%s is not a type", name, v.Sel.Name)
+	} else {
+		ctx.handleErrorf(v.Pos(), "undefined: %s", name)
 	}
-	panic(ctx.newCodeErrorf(v.Pos(), "undefined: %s", name))
+	return types.Typ[types.Invalid]
 }
 
 /*-----------------------------------------------------------------------------
@@ -198,25 +222,38 @@ Name context:
 
 // ---------------------------------------------------------------------------*/
 
-func toIdentType(ctx *blockCtx, ident *ast.Ident) types.Type {
+func toIdentType(ctx *blockCtx, ident *ast.Ident) (ret types.Type) {
+	var obj types.Object
+	if rec := ctx.recorder(); rec != nil {
+		defer func() {
+			if obj != nil {
+				rec.Use(ident, obj)
+			}
+		}()
+	}
 	if ctx.tlookup != nil {
 		if typ := ctx.tlookup.Lookup(ident.Name); typ != nil {
+			obj = typ.Obj()
 			return typ
 		}
 	}
 	v, builtin := lookupType(ctx, ident.Name)
 	if isBuiltin(builtin) {
-		panic(ctx.newCodeErrorf(ident.Pos(), "use of builtin %s not in function call", ident.Name))
+		ctx.handleErrorf(ident.Pos(), "use of builtin %s not in function call", ident.Name)
+		return types.Typ[types.Invalid]
 	}
 	if t, ok := v.(*types.TypeName); ok {
+		obj = t
 		return t.Type()
 	}
 	if v, _ := lookupPkgRef(ctx, nil, ident, objPkgRef); v != nil {
 		if t, ok := v.(*types.TypeName); ok {
+			obj = t
 			return t.Type()
 		}
 	}
-	panic(ctx.newCodeErrorf(ident.Pos(), "%s is not a type", ident.Name))
+	ctx.handleErrorf(ident.Pos(), "%s is not a type", ident.Name)
+	return types.Typ[types.Invalid]
 }
 
 // TODO: optimization
@@ -257,8 +294,8 @@ func (p *checkRedecl) chkRedecl(ctx *blockCtx, name string, pos token.Pos) bool
 		return false
 	}
 	if opos, ok := p.names[name]; ok {
-		npos := ctx.Position(pos)
-		ctx.handleCodeErrorf(&npos, "%v redeclared\n\t%v other declaration of %v",
+		ctx.handleErrorf(
+			pos, "%v redeclared\n\t%v other declaration of %v",
 			name, ctx.Position(opos), name)
 		return true
 	}
@@ -272,6 +309,7 @@ func toStructType(ctx *blockCtx, v *ast.StructType) *types.Struct {
 	fields := make([]*types.Var, 0, len(fieldList))
 	tags := make([]string, 0, len(fieldList))
 	chk := newCheckRedecl()
+	rec := ctx.recorder()
 	for _, field := range fieldList {
 		typ := toType(ctx, field.Type)
 		if len(field.Names) == 0 { // embedded
@@ -282,18 +320,25 @@ func toStructType(ctx *blockCtx, v *ast.StructType) *types.Struct {
 			if t, ok := typ.(*types.Named); ok { // #1196: embedded type should ensure loaded
 				ctx.loadNamed(ctx.pkg, t)
 			}
-			fld := types.NewField(token.NoPos, pkg, name, typ, true)
+			ident := parseTypeEmbedName(field.Type)
+			fld := types.NewField(ident.NamePos, pkg, name, typ, true)
 			fields = append(fields, fld)
 			tags = append(tags, toFieldTag(field.Tag))
+			if rec != nil {
+				rec.Def(ident, fld)
+			}
 			continue
 		}
 		for _, name := range field.Names {
 			if chk.chkRedecl(ctx, name.Name, name.NamePos) {
 				continue
 			}
-			fld := types.NewField(token.NoPos, pkg, name.Name, typ, false)
+			fld := types.NewField(name.NamePos, pkg, name.Name, typ, false)
 			fields = append(fields, fld)
 			tags = append(tags, toFieldTag(field.Tag))
+			if rec != nil {
+				rec.Def(name, fld)
+			}
 		}
 	}
 	return types.NewStruct(fields, tags)
@@ -363,6 +408,7 @@ func toInterfaceType(ctx *blockCtx, v *ast.InterfaceType) types.Type {
 	if methodsList == nil {
 		return types.NewInterfaceType(nil, nil)
 	}
+	var rec = ctx.recorder()
 	var pkg = ctx.pkg.Types
 	var methods []*types.Func
 	var embeddeds []types.Type
@@ -375,9 +421,13 @@ func toInterfaceType(ctx *blockCtx, v *ast.InterfaceType) types.Type {
 			embeddeds = append(embeddeds, typ)
 			continue
 		}
-		name := m.Names[0].Name
+		name := m.Names[0]
 		sig := toFuncType(ctx, m.Type.(*ast.FuncType), nil, nil)
-		methods = append(methods, types.NewFunc(token.NoPos, pkg, name, sig))
+		mthd := types.NewFunc(name.NamePos, pkg, name.Name, sig)
+		methods = append(methods, mthd)
+		if rec != nil {
+			rec.Def(name, mthd)
+		}
 	}
 	intf := types.NewInterfaceType(methods, embeddeds).Complete()
 	return intf
