@@ -431,7 +431,7 @@ for _, a = range b {
 
 func TestErrInitFunc(t *testing.T) {
 	codeErrorTest(t,
-		`./bar.gop:2:1: func init must have no arguments and no return values`, `
+		`./bar.gop:2:6: func init must have no arguments and no return values`, `
 func init(v byte) {
 }
 `)
@@ -916,7 +916,7 @@ println "hello"
 }
 
 func TestErrVarInFunc(t *testing.T) {
-	codeErrorTest(t, `./bar.gop:6:10: too few arguments in call to set("box")
+	codeErrorTest(t, `./bar.gop:6:10: not enough arguments in call to set
 	have (untyped string)
 	want (name string, v int)
 ./bar.gop:7:10: undefined: a`, `
